@@ -20,7 +20,6 @@
 #' @param threads how many threads to use in the optimization if using "gurobi" as the solver. Default will use all available threads
 #'
 #' @return A list containing the following elements:
-#' \itemize{
 #'     \item{valueIP, valueLP: }{integer and linear programming scaled objective values}
 #'     \item{n_smds: }{number of standardized mean differences contributing to the objective values
 #' (multiply the scaled objective values by this number to get the true objective values)}
@@ -29,7 +28,6 @@
 #'     that were selected with randomness}
 #'     \item{pr: }{linear programming solution, with rows corresponding to the strata and columns to the units}
 #'     \item{selection: }{vector of selected strata for each unit in the initial stratum to be split}
-#' }
 #'
 #' @examples
 #' # Generate a small data set
@@ -245,7 +243,9 @@ split_stratum <- function(z, X, strata, ist, nc, nt,
         epsIP[(2*(s-1)+1), ] <- pmax(0, eval[2*s, ] - eval[2*s-1, ])
         epsIP[2*s, ] <- pmax(0, eval[2*s-1, ] - eval[2*s, ])
       }
-      epsIP[(2*S + 1),]<-apply(epsIP[1:(2*S),, drop = FALSE], 2, max, na.rm = TRUE)
+      epsIP[(2*S + 1),]<-apply(epsIP[1:(2*S),, drop = FALSE], 2, function(x) {
+        if (all(is.na(x))) return(NA) else return(max(x, na.rm = TRUE))
+      })
       rownames(epsIP)<-c(paste(c("Pos eps","Neg eps"), rep(1:S, each = 2)), "max")
       if (!is.null(colnames(X))) colnames(epsIP)<-colnames(X)
       epsIP_nona <- epsIP
@@ -261,9 +261,15 @@ split_stratum <- function(z, X, strata, ist, nc, nt,
     best_valueIP <- v
     v <- NA
     st <- which(st_mat == 1, arr.ind = TRUE)[, 1]
+    if (length(st) == 0) {
+      stop("Error in split_stratum(): No valid assignment found in integer programming solution.", call. = FALSE)
+    }
     best_selection <- st
   }
 
+  if (is.null(best_selection) || length(best_selection) == 0) {
+    stop("Error in split_stratum(): No valid selection found after randomized rounding.", call. = FALSE)
+  }
 
   return(list(valueIP = best_valueIP, valueLP = v, n_smds = wEach * J * Sadj + wMax, n_fracs = n_fracs,
               rand_c_prop = rand_c_prop, rand_t_prop = rand_t_prop, pr = pr, selection = best_selection))
